Index: main/waeup.kwarapoly/trunk/src/waeup/kwarapoly/students/tests/test_browser.py
===================================================================
--- main/waeup.kwarapoly/trunk/src/waeup/kwarapoly/students/tests/test_browser.py	(revision 12910)
+++ main/waeup.kwarapoly/trunk/src/waeup/kwarapoly/students/tests/test_browser.py	(revision 12911)
@@ -525,5 +525,6 @@
             self.student['studycourse']['200']['COURSE1'].course.credits, 100000)
         self.browser.getControl("Register course list").click()
-        self.assertTrue('Course list has been registered' in self.browser.contents)
+        self.assertTrue(
+            'Course list has been registered' in self.browser.contents)
         self.assertEqual(self.student.state, 'courses registered')
         return
@@ -544,8 +545,13 @@
         self.student['studycourse'].entry_session = 2014
         self.browser.open(self.student_path)
+        self.assertRaises(
+            LinkNotFoundError,
+            self.browser.getLink, 'Get Matriculation Number')
+        self.student['studycourse'].entry_session = 2015
+        self.browser.open(self.student_path)
         self.browser.getLink("Get Matriculation Number").click()
-        self.assertTrue('Matriculation number ND/14/dep1/FT/001 assigned.'
+        self.assertTrue('Matriculation number ND/15/dep1/FT/001 assigned.'
             in self.browser.contents)
-        self.assertEqual(self.student.matric_number, 'ND/14/dep1/FT/001')
+        self.assertEqual(self.student.matric_number, 'ND/15/dep1/FT/001')
         self.assertRaises(
             LinkNotFoundError,
@@ -556,4 +562,4 @@
         logcontent = open(logfile).read()
         self.assertTrue('W1000000 - waeup.kwarapoly.students.browser.StudentGetMatricNumberPage - '
-                        'W1000000 - ND/14/dep1/FT/001 assigned' in logcontent)
-        return
+                        'W1000000 - ND/15/dep1/FT/001 assigned' in logcontent)
+        return
Index: main/waeup.kwarapoly/trunk/src/waeup/kwarapoly/students/utils.py
===================================================================
--- main/waeup.kwarapoly/trunk/src/waeup/kwarapoly/students/utils.py	(revision 12910)
+++ main/waeup.kwarapoly/trunk/src/waeup/kwarapoly/students/utils.py	(revision 12911)
@@ -357,4 +357,6 @@
         entry_mode = getattr(
             student.get('studycourse', None), 'entry_mode', None)
+        if entry_session < 2015:
+            return _('Available from session 2015/2016'), None
         if student.state not in (PAID, ):
             return _('Wrong state.'), None
Index: main/waeup.kwarapoly/trunk/src/waeup/kwarapoly/university/tests.py
===================================================================
--- main/waeup.kwarapoly/trunk/src/waeup/kwarapoly/university/tests.py	(revision 12910)
+++ main/waeup.kwarapoly/trunk/src/waeup/kwarapoly/university/tests.py	(revision 12911)
@@ -35,4 +35,5 @@
         utils = getUtility(IStudentsUtils)
         self.student.matric_number = None
+        self.student['studycourse'].entry_session = 2015
         IWorkflowState(self.student).setState('school fee paid')
         msg, mnumber = utils.setMatricNumber(self.student)
@@ -40,5 +41,4 @@
         self.assertEqual(mnumber, None)
         self.student['studycourse'].entry_mode = 'nd_ft'
-        self.student['studycourse'].entry_session = 2013
         msg, mnumber = utils.setMatricNumber(self.student)
         exporter = CustomDepartmentExporter()
@@ -49,5 +49,5 @@
             'code,faculty_code,title,title_prefix,users_with_local_roles,'
             'next_matric_dict\r\n'
-            'dep1,fac1,Unnamed Department,department,[],{2013: 2}\r\n'
+            'dep1,fac1,Unnamed Department,department,[],{2015: 2}\r\n'
             )
         return

Index: main/waeup.kwarapoly/trunk/src/waeup/kwarapoly/students/tests/test_utils.py
===================================================================
--- main/waeup.kwarapoly/trunk/src/waeup/kwarapoly/students/tests/test_utils.py	(revision 12910)
+++ main/waeup.kwarapoly/trunk/src/waeup/kwarapoly/students/tests/test_utils.py	(revision 12911)
@@ -51,23 +51,23 @@
         self.student.matric_number = None
         msg, mnumber = utils.setMatricNumber(self.student)
+        self.assertEqual(msg, 'Available from session 2015/2016')
+        self.student['studycourse'].entry_mode = 'nd_ft'
+        self.student['studycourse'].entry_session = 2015
+        msg, mnumber = utils.setMatricNumber(self.student)
+        self.assertEqual(mnumber, None)
         self.assertEqual(msg, 'Wrong state.')
         IWorkflowState(self.student).setState('school fee paid')
         msg, mnumber = utils.setMatricNumber(self.student)
-        self.assertEqual(msg, 'Matriculation number cannot be set.')
-        self.assertEqual(mnumber, None)
-        self.student['studycourse'].entry_mode = 'nd_ft'
-        self.student['studycourse'].entry_session = 2013
-        msg, mnumber = utils.setMatricNumber(self.student)
-        self.assertEqual(self.student.matric_number, 'ND/13/dep1/FT/001')
+        self.assertEqual(self.student.matric_number, 'ND/15/dep1/FT/001')
         self.assertEqual(
             self.app['faculties']['fac1']['dep1'].next_matric_dict,
-            {2013: 2})
-        # setting a new matric number in 2014, extends next_matric_dict
-        self.student['studycourse'].entry_session = 2014
+            {2015: 2})
+        # setting a new matric number in 2016, extends next_matric_dict
+        self.student['studycourse'].entry_session = 2016
         self.student.matric_number = None
         msg, mnumber = utils.setMatricNumber(self.student)
         self.assertEqual(
             self.app['faculties']['fac1']['dep1'].next_matric_dict,
-            {2013: 2, 2014: 2})
+            {2015: 2, 2016: 2})
         # setting a new matric number in 2014 again, increases the counter
         self.student.matric_number = None
@@ -75,5 +75,5 @@
         self.assertEqual(
             self.app['faculties']['fac1']['dep1'].next_matric_dict,
-            {2013: 2, 2014: 3})
+            {2015: 2, 2016: 3})
         # matric number must not exist
         msg, mnumber = utils.setMatricNumber(self.student)